Limitations
===========

Sensors support
---------------

Ignition Gazebo supports a wide variety of `sensors <https://ignitionrobotics.org/docs/citadel/comparison#sensors>`_,
like cameras, lidars, ...
However, ScenarI/O and consequently gym-ignition are not yet able to extract data from sensors.
Follow :issue:`199` if you're interested in sensors support.
